@@ -437,6 +437,10 @@ class CentralUnitAPI(ABC):
 
         device = self._devices_map[device_id]
 
+        # temp workaround
+        if isinstance(state, float):
+            state = int(state)
+
         if isinstance(device, SwitchBeeDimmer):
             assert isinstance(state, (str, int))
             device.brightness = state  # type: ignore
